from distutils.core import setup

setup(
    name = 'strawluffy121',
    version = '1.1.2',
    py_modules = ['strawluffy121'],
    author = 'luffy',
    author_email = 'ricky.ye@qq.com',
    url = '',
    description = 'A simple printer of nested lists',
)

